django-sitetables documentation
===============================
https://github.com/idlesign/django-sitetables



Description
-----------

*Reusable application for Django featuring DataTables integration*

**Offers:**

* Various data sources support: models, query sets, list of dicts.
* ``DataTables`` plugins support: styling, internationalization, etc.
* Template tags for easy js and css inclusion.
* Template tags for DOM-based tables.



Requirements
------------

1. Python 3
2. Django 1.10+



Table of Contents
-----------------

.. toctree::
    :maxdepth: 2

    quickstart
    plugins
